@@ -11,10 +11,8 @@ class BscHelper(EvmBaseHelper):
     DEFAULT_DEX = 'PCS' #PancakeSwap
 
     def __init__(self, dex_name=None, custom_rpc=None):
-        w3 = Web3(Web3.HTTPProvider(config.general_params['BSC_RPC_URL'] if custom_rpc is None else custom_rpc))
-        w3.middleware_onion.inject(geth_poa_middleware, layer=0)
-
-        super().__init__(w3, chain_data)
+        self.w3 = Web3(Web3.HTTPProvider(config.general_params['BSC_RPC_URL'] if custom_rpc is None else custom_rpc))
+        self.w3.middleware_onion.inject(geth_poa_middleware, layer=0)
 
         self.dex_router = EvmBaseHelper.get_dex_router_contract(
             self.w3,
