@@ -12,13 +12,11 @@ class PolyHelper(EvmBaseHelper):
     DEFAULT_DEX = "QS"
 
     def __init__(self, dex_name=None, custom_rpc=None):
-        w3 = Web3(Web3.HTTPProvider(config.general_params['POLY_RPC_URL'] if custom_rpc is None else custom_rpc))
-        w3.middleware_onion.inject(geth_poa_middleware, layer=0)
-
-        super().__init__(w3, chain_data)
+        self.w3 = Web3(Web3.HTTPProvider(config.general_params['POLY_RPC_URL'] if custom_rpc is None else custom_rpc))
+        self.w3.middleware_onion.inject(geth_poa_middleware, layer=0)
 
         self.dex_router = EvmBaseHelper.get_dex_router_contract(
-            w3,
+            self.w3,
             chain_data,
             PolyHelper.DEFAULT_DEX if dex_name is None else dex_name
         )
